@@ -275,19 +275,35 @@ DefaultAction.prototype.mouseMoveEvent = function(event) {
 
 DefaultAction.prototype.mouseReleaseEvent = function(event) {
     var persistentSelection = RSettings.getBoolValue("GraphicsView/PersistentSelection", false);
-    var view, range, strictRange, entityId;
+    var entityId;
 
     var shiftPressed = (event.modifiers() & Qt.ShiftModifier) > 0 || (event.modifiers() & Qt.ControlModifier) > 0 || persistentSelection===true;
 
     if (event.button() === Qt.LeftButton) {
         switch (this.state) {
         case DefaultAction.State.Dragging:
+
+            // handle clicks on reference points:
+            this.d2Model = event.getModelPosition();
+            this.d2Screen = event.getScreenPosition();
+            var view = event.getGraphicsView();
+            if (this.d1Screen.equalsFuzzy(this.d2Screen, 10)) {
+                // mouse press and release at same position (click):
+                var referencePoint = view.getClosestReferencePoint(this.d1Screen, this.minPickRangePixels);
+                if (referencePoint.isValid() && !referencePoint.isIgnore() && !RSettings.getIgnoreAllReferencePoints()) {
+                    this.d1Model = referencePoint;
+                    var op = new RClickReferencePointOperation(this.d1Model);
+                    this.di.applyOperation(op);
+                    this.setState(DefaultAction.State.Neutral);
+                    return;
+                }
+            }
+
+
             // find selectable entity under cursor:
             entityId = this.getEntityId(event, false, true);
 
             //qDebug("entityId: ", entityId);
-            //var e = this.document.queryEntity(entityId);
-            //if (!isNull(e)) qDebug("parentId: ", e.getParentId());
 
             if (entityId !== -1) {
                 if (shiftPressed && this.document.isSelected(entityId)) {
@@ -646,10 +662,14 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
         }
         */
 
+        // block editing with double click might be disabled globally:
         if (RSettings.getBoolValue("GraphicsView/DoubleClickEditBlock", true)===true) {
-            include("scripts/Block/Block.js");
-            EAction.handleUserMessage(qsTr("Editing block '%1'<br>Choose <i>Block > Return to Main Drawing</i> when done").arg(entity.getReferencedBlockName()));
-            Block.editBlock(this.di, entity.getReferencedBlockName());
+            // block editing with double click might be disabled for this entity:
+            if (entity.getCustomBoolProperty("QCAD", "DoubleClickEditBlock", true)===true) {
+                include("scripts/Block/Block.js");
+                EAction.handleUserMessage(qsTr("Editing block '%1'<br>Choose <i>Block > Return to Main Drawing</i> when done").arg(entity.getReferencedBlockName()), false);
+                Block.editBlock(this.di, entity.getReferencedBlockName());
+            }
         }
     }
     else if (isHatchEntity(entity)) {
