@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -85,6 +85,27 @@ Dimension.prototype.initUiOptions = function(resume, optionsToolBar) {
     WidgetFactory.initLineEdit(lowerToleranceLineEdit, true);
 
     this.initScaleCombo();
+
+    // not a layout block: hide auto checkbox:
+    var doc = this.getDocument();
+    if (!isNull(doc)) {
+        var block = doc.queryCurrentBlock();
+        if (!isNull(block) && block.hasLayout() && block.isModelSpace()) {
+            var cbAutoAction = optionsToolBar.findChild("AutoScaleAction");
+            if (!isNull(cbAutoAction)) {
+                cbAutoAction.visible = false;
+                var cbAuto = optionsToolBar.findChild("AutoScale");
+                cbAuto.checked = false;
+                if (!resume) {
+                    // don't (re-)initialize or save state of auto checkbox:
+                    cbAuto.setProperty("Loaded", true);
+                    cbAuto.setProperty("Saved", true);
+                }
+                var scaleCombo = optionsToolBar.findChild("Scale");
+                scaleCombo.setEnabled(true);
+            }
+        }
+    }
     
     // if we are resuming, restore previous values (automatic)
     // it not, keep them empty.
@@ -237,3 +258,48 @@ Dimension.prototype.getScaleString = function() {
 Dimension.prototype.parseScale = function(scaleString) {
     return RMath.parseScale(scaleString);
 };
+
+/**
+ * Automatically adjust the dimension scale based on the context of a viewport.
+ */
+Dimension.prototype.autoAdjustScale = function(pos) {
+    var optionsToolBar = EAction.getOptionsToolBar();
+    var cbAuto = optionsToolBar.findChild("AutoScale");
+    if (isNull(cbAuto) || !cbAuto.checked) {
+        return;
+    }
+
+    var doc = this.getDocument();
+
+    // are we in a layout block:
+    var block = doc.queryCurrentBlock();
+    if (isNull(block) || !block.hasLayout()) {
+        return;
+    }
+
+    // get scale of underlying viewport:
+    var scale = undefined;
+    var viewportIds = doc.queryAllEntities(false, false, RS.EntityViewport);
+    for (var i=0; i<viewportIds.length; i++) {
+        var viewportId = viewportIds[i];
+        var viewport = doc.queryEntityDirect(viewportId);
+        var box = viewport.getBoundingBox();
+        if (box.containsPoint(pos)) {
+            scale = viewport.getScale();
+            break;
+        }
+    }
+
+    // no viewport under pos:
+    if (isNull(scale)) {
+        scale = 1.0;
+    }
+
+    // set scale of dimension according to viewport:
+    var scaleCombo = optionsToolBar.findChild("Scale");
+    if (isNull(scaleCombo)) {
+        return;
+    }
+
+    scaleCombo.currentText = RUnit.doubleToStringDec(scale, 3);
+};
